@@ -3,63 +3,66 @@
 #' Converts values from one specific position of a Risoe.BINfileData S4-class
 #' object to an RLum.Analysis object.
 #'
-#' The \code{\linkS4class{RLum.Analysis}} object requires a set of curves for
-#' specific further protocol analyses. However, the
-#' \code{\linkS4class{Risoe.BINfileData}} usually contains a set of curves for
-#' different aliquots and different protocol types that may be mixed up.
-#' Therefore, a conversion is needed.
+#' The [RLum.Analysis-class] object requires a set of curves for
+#' specific further protocol analyses. However, the [Risoe.BINfileData-class] 
+#' usually contains a set of curves for different aliquots and different 
+#' protocol types that may be mixed up. Therefore, a conversion is needed.
 #'
-#' @param object \code{\linkS4class{Risoe.BINfileData}} (\bold{required}):
-#' \code{Risoe.BINfileData} object
+#' @param object [Risoe.BINfileData-class] (**required**):
+#' `Risoe.BINfileData` object
 #'
-#' @param pos \code{\link{numeric}} (optional): position number of the
-#' \code{Risoe.BINfileData} object for which the curves are stored in the
-#' \code{RLum.Analysis} object. If \code{length(position)>1} a list of \code{RLum.Analysis} objects
-#' is returned. If nothing is provided every position will be converted. If the position is not valid \code{NA} is
-#' returned.
+#' @param pos [numeric] (*optional*): position number of the `Risoe.BINfileData` 
+#' object for which the curves are stored in the `RLum.Analysis` object. 
+#' If `length(position)>1` a list of `RLum.Analysis` objects is returned. 
+#' If nothing is provided every position will be converted. 
+#' If the position is not valid `NA` is returned.
 #'
-#' @param grain \code{\link{vector}, \link{numeric}} (optional): grain number from
-#' the measurement to limit the converted data set (e.g., \code{grain =
-#' c(1:48)}). Please be aware that this option may lead to unwanted effects, as the output
-#' is strictly limited to the choosen grain number for all position numbers
+#' @param grain [vector], [numeric] (*optional*): 
+#' grain number from the measurement to limit the converted data set 
+#' (e.g., `grain = c(1:48)`). Please be aware that this option may lead to 
+#' unwanted effects, as the output is strictly limited to the choosen grain 
+#' number for all position numbers
 #'
-#' @param run \code{\link{vector}, \link{numeric}} (optional): run number from
-#' the measurement to limit the converted data set (e.g., \code{run =
-#' c(1:48)}).
+#' @param run [vector], [numeric] (*optional*): 
+#' run number from the measurement to limit the converted data set 
+#' (e.g., `run = c(1:48)`).
 #'
-#' @param set \code{\link{vector}, \link{numeric}} (optional): set number from
-#' the measurement to limit the converted data set (e.g., \code{set =
-#' c(1:48)}).
+#' @param set [vector], [numeric] (*optional*): 
+#' set number from the measurement to limit the converted data set 
+#' (e.g., `set = c(1:48)`).
 #'
-#' @param ltype \code{\link{vector}, \link{character}} (optional): curve type
-#' to limit the converted data. Commonly allowed values are: \code{IRSL}, \code{OSL},
-#' \code{TL}, \code{RIR}, \code{RBR} and \code{USER} (see also \code{\linkS4class{Risoe.BINfileData}})
+#' @param ltype [vector], [character] (*optional*): 
+#' curve type to limit the converted data. Commonly allowed values are: 
+#' `IRSL`, `OSL`, `TL`, `RIR`, `RBR` and `USER` 
+#' (see also [Risoe.BINfileData-class])
 #'
-#' @param dtype \code{\link{vector}, \link{character}} (optional): data type to
-#' limit the converted data. Commonly allowed values are listed in \code{\linkS4class{Risoe.BINfileData}}
+#' @param dtype [vector], [character] (*optional*): 
+#' data type to limit the converted data. Commonly allowed values are 
+#' listed in [Risoe.BINfileData-class]
 #'
-#' @param protocol \code{\link{character}} (optional): sets protocol type for
-#' analysis object. Value may be used by subsequent analysis functions.
+#' @param protocol [character] (*optional*): 
+#' sets protocol type for analysis object. Value may be used by subsequent 
+#' analysis functions.
 #'
-#' @param keep.empty \code{\link{logical}} (with default): If \code{TRUE} (default)
-#' an \code{RLum.Analysis} object is returned even if it does not contain any
-#' records. Set to \code{FALSE} to discard all empty objects.
+#' @param keep.empty [logical] (*with default*): 
+#' If `TRUE` (default) an `RLum.Analysis` object is returned even if it does 
+#' not contain any records. Set to `FALSE` to discard all empty objects.
 #'
-#' @param txtProgressBar \link{logical} (with default): enables or disables
-#' \code{\link{txtProgressBar}}.
+#' @param txtProgressBar [logical] (*with default*): 
+#' enables or disables [txtProgressBar].
 #'
-#' @return Returns an \code{\linkS4class{RLum.Analysis}} object.
+#' @return Returns an [RLum.Analysis-class] object.
 #'
-#' @note The \code{protocol} argument of the \code{\linkS4class{RLum.Analysis}}
+#' @note 
+#' The `protocol` argument of the [RLum.Analysis-class]
 #' object is set to 'unknown' if not stated otherwise.
 #'
-#' @section Function version: 0.4.1
+#' @section Function version: 0.4.2
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#' @author 
+#' Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
 #'
-#' @seealso \code{\linkS4class{Risoe.BINfileData}}, \code{\linkS4class{RLum.Analysis}}, \code{\link{read_BIN2R}}
-#'
-#' @references #
+#' @seealso [Risoe.BINfileData-class], [RLum.Analysis-class], [read_BIN2R]
 #'
 #' @keywords manip
 #'
@@ -71,6 +74,7 @@
 #' ##convert values for position 1
 #' Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, pos = 1)
 #'
+#' @md
 #' @export
 Risoe.BINfileData2RLum.Analysis<- function(
   object,
@@ -98,6 +102,7 @@ Risoe.BINfileData2RLum.Analysis<- function(
 
   if (is.null(pos)) {
     pos <- unique(object@METADATA[["POSITION"]])
+
   } else{
     ##get and check valid positions and remove invalid numbers from the input
     positions.valid <- unique(object@METADATA[, "POSITION"])
@@ -124,10 +129,11 @@ Risoe.BINfileData2RLum.Analysis<- function(
       grain <- unique(object@METADATA[,"GRAIN"])
 
     }else{
-      if(length(setdiff(grain, grain.valid)) > 0){
-        grain.valid <- unique(object@METADATA[,"GRAIN"])
 
-        warning(paste0("[Risoe.BINfileData2RLum.Analysis()] invalid grain number skipped: ",
+      grain.valid <- unique(object@METADATA[,"GRAIN"])
+      if(length(setdiff(grain, grain.valid)) > 0){
+
+        warning(paste0("[Risoe.BINfileData2RLum.Analysis()] Invalid grain number skipped: ",
                        paste(setdiff(grain, grain.valid), collapse = ", ")), call. = FALSE)
 
         grain <- intersect(grain, grain.valid)
@@ -286,7 +292,7 @@ Risoe.BINfileData2RLum.Analysis<- function(
 
 
         }
-        
+
         ##create curve object
         object <- set_RLum(
           class = "RLum.Analysis",
@@ -302,7 +308,7 @@ Risoe.BINfileData2RLum.Analysis<- function(
 
         ##add unique id of RLum.Analysis object to each curve object as .pid using internal function
         .set_pid(object)
-        
+
         return(object)
 
       })
@@ -314,7 +320,7 @@ Risoe.BINfileData2RLum.Analysis<- function(
     ##this is necessary to not break with previous code, i.e. if only one element is included
     ##the output is RLum.Analysis and not a list of it
     if(length(object) == 1){
-      
+
       # special case: single grain data with only 1 position produces a nested list
       # the outer one is of length 1, the nested list has length 100 (100 grains)
       if (is.list(object[[1]]) && length(object[[1]]) > 1)
